pywws.Upload — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# pywws.Upload

## Introduction

Ce module téléverse des fichiers sur (en général) un site Web via ftp/sftp ou copie les fichiers dans un répertoire local (par exemple, si vous exécutez pywws sur votre propre serveur web). Les détails de destination de téléversement sont stockés dans le fichier `weather.ini` dans votre répertoire de données. La seule façon de régler ces détails est d’éditer le fichier. Exécuter Upload.py une fois pour définir les valeurs par défaut, que vous pouvez ensuite modifier. Voici ce que vous êtes susceptible de trouver lorsque vous éditez `weather.ini`:

    [ftp]
    secure = False
    directory = public_html/weather/data/
    local site = False
    password = secret
    site = ftp.username.your_isp.co.uk
    user = username

Ce sont, je l’espère, des options assez évidentes. `local site` vous permet de passer de téléversement sur un site distant, à la copie vers un site local. Si vous réglez `local site = True`, vous pouvez supprimer les lignes``secure``, `site`, `user` et `password`.

`directory` est le nom d’un répertoire dans lequel tous les fichiers téléversés seront déposés. Ce qui dépendra de la structure de votre site et du type d’hôte que vous utilisez. Votre fournisseur d’hébergement doit être en mesure de vous dire ce que vous devez utiliser pour `site` et `user`. Vous devriez déjà avoir choisi un `password`.

L’option `secure` vous permet de passer de ftp normal à sftp (ftp sur ssh). Certains fournisseurs d’hébergement l’offre comme mécanisme de chargement plus sûr, alors vous devriez probablement l’utiliser lorsque disponible.

## API détaillé

Upload files to a web server by ftp or copy them to a local directory

    usage: python -m pywws.Upload [options] data_dir file [file...]
    options are:
     -h or --help    display this help
    data_dir is the root directory of the weather data
    file is a file to be uploaded

Le nom d’usager et les détails du site ftp sont lues à partir du fichier weather.ini dans data_dir.

Fonctions

`Upload`(params, files) |
`main`([argv]) |

`pywws.Upload.` `Upload`(params, files)

`pywws.Upload.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »